summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authordkf <donal.k.fellows@manchester.ac.uk>2015-03-17 19:47:32 (GMT)
committerdkf <donal.k.fellows@manchester.ac.uk>2015-03-17 19:47:32 (GMT)
commit4caaca704125b985e050ba4a728d9dd52945c7c5 (patch)
tree73d8534227c6a76c358c72e413e27f99f8337ec5
parentbe8897bd8b2b61b6206329f641a60878d1404a41 (diff)
parente54038086f492625fa4870aa220ad7b4b746b87d (diff)
downloadtcl-4caaca704125b985e050ba4a728d9dd52945c7c5.zip
tcl-4caaca704125b985e050ba4a728d9dd52945c7c5.tar.gz
tcl-4caaca704125b985e050ba4a728d9dd52945c7c5.tar.bz2
merge trunk
-rw-r--r--README2
-rw-r--r--changes34
-rw-r--r--doc/CrtChannel.32
-rw-r--r--doc/Encoding.348
-rw-r--r--doc/exec.n67
-rw-r--r--doc/file.n8
-rw-r--r--doc/glob.n8
-rw-r--r--doc/open.n4
-rw-r--r--doc/socket.n1
-rw-r--r--doc/tcltest.n8
-rw-r--r--doc/tclvars.n9
-rw-r--r--generic/regcomp.c14
-rw-r--r--generic/regexec.c4
-rw-r--r--generic/regguts.h2
-rw-r--r--generic/tcl.h4
-rw-r--r--generic/tclCompCmdsGR.c4
-rw-r--r--generic/tclIO.c20
-rw-r--r--generic/tclVar.c2
-rw-r--r--library/init.tcl2
-rw-r--r--library/tzdata/Africa/Asmera6
-rw-r--r--library/tzdata/America/Cancun171
-rw-r--r--library/tzdata/America/Santiago171
-rw-r--r--library/tzdata/Antarctica/Palmer171
-rw-r--r--library/tzdata/Asia/Aden7
-rw-r--r--library/tzdata/Asia/Bahrain8
-rw-r--r--library/tzdata/Asia/Kuwait7
-rw-r--r--library/tzdata/Asia/Muscat7
-rw-r--r--library/tzdata/Atlantic/Reykjavik11
-rw-r--r--library/tzdata/Pacific/Easter172
-rw-r--r--macosx/tclMacOSXNotify.c3
-rw-r--r--tests/io.test19
-rw-r--r--tests/lreplace.test9
-rwxr-xr-xtools/tcltk-man2html.tcl6
-rwxr-xr-xunix/configure2
-rw-r--r--unix/configure.in2
-rw-r--r--unix/tcl.spec2
-rw-r--r--unix/tclConfig.h.in26
-rwxr-xr-xwin/configure2
-rw-r--r--win/configure.in2
39 files changed, 161 insertions, 886 deletions
diff --git a/README b/README
index 0fb128d..f63e0e7 100644
--- a/README
+++ b/README
@@ -1,5 +1,5 @@
README: Tcl
- This is the Tcl 8.6.3 source distribution.
+ This is the Tcl 8.6.4 source distribution.
http://sourceforge.net/projects/tcl/files/Tcl/
You can get any source release of Tcl from the URL above.
diff --git a/changes b/changes
index 79a242d..8dffa37 100644
--- a/changes
+++ b/changes
@@ -8492,4 +8492,38 @@ include ::oo::class (fellows)
--- Released 8.6.3, November 12, 2014 --- http://core.tcl.tk/tcl/ for details
+2014-11-21 (bug)[743338] Win: socket error encoding (ladayaroslav,nijtmans)
+
+2014-12-01 (bug) restore tbcload/tclcompiler support (kupries)
+
+2014-12-03 (bug)[0c043a] Fix compiled [set var($) val] (porter)
+
+2014-12-04 (bug)[d2ffcc] Limit $... and bareword parsing to ASCII (ladayaroslav,porter)
+ *** POTENTIAL INCOMPATIBILITY ***
+
+2014-12-06 (bug)[c6cd4a] Win: hang in async socket connection (shults,nadkarni)
+
+2014-12-10 tzdata updated to Olson's tzdata2014j (venkat)
+
+2014-12-13 fix header files installation on OS X (houben)
+
2014-12-17 (TIP 427) [fconfigure $h -connecting, -peername, -sockname] (oehlmann,rmax)
+
+2014-12-18 (bug)[af08c8] Crash in full finalize encoding teardown (porter)
+
+2014-12-18 (bug)[7c187a] [chan copy] crash (io-53.17) (benno,porter)
+
+2015-01-26 (bug)[df0848] Trouble with INFINITY macro (dower,nijtmans)
+
+2015-01-29 (bug) Stop crashes when extension var resolvers misbehave (porter)
+
+2015-01-29 (bug)[088727] [read] past EOF (io-73.4) (fenugrec,porter)
+
+2015-02-11 tzdata updated to Olson's tzdata2015a (venkat)
+
+2015-02-20 (bug)[32b615] Fix compiled [lreplace] (lreplace-4.[345]) (aspect)
+
+2015-03-10 (enhancement) Revise OS X notifier for better Cocoa (walzer)
+ *** POTENTIAL INCOMPATIBILITY ***
+
+--- Released 8.6.4, March 12, 2015 --- http://core.tcl.tk/tcl/ for details
diff --git a/doc/CrtChannel.3 b/doc/CrtChannel.3
index 1c5c665..2335de1 100644
--- a/doc/CrtChannel.3
+++ b/doc/CrtChannel.3
@@ -336,7 +336,7 @@ typedef struct Tcl_ChannelType {
It is not necessary to provide implementations for all channel
operations. Those which are not necessary may be set to NULL in the
struct: \fIblockModeProc\fR, \fIseekProc\fR, \fIsetOptionProc\fR,
-\fIgetOptionProc\fR, and \fIclose2Proc\fR, in addition to
+\fIgetOptionProc\fR, \fIgetHandleProc\fR, and \fIclose2Proc\fR, in addition to
\fIflushProc\fR, \fIhandlerProc\fR, \fIthreadActionProc\fR, and
\fItruncateProc\fR. Other functions that cannot be implemented in a
meaningful way should return \fBEINVAL\fR when called, to indicate
diff --git a/doc/Encoding.3 b/doc/Encoding.3
index 1478c35..6664b3b 100644
--- a/doc/Encoding.3
+++ b/doc/Encoding.3
@@ -257,47 +257,13 @@ is filled with the corresponding number of bytes that were stored in
.PP
\fBTcl_WinUtfToTChar\fR and \fBTcl_WinTCharToUtf\fR are
Windows-only convenience
-functions for converting between UTF-8 and Windows strings. On Windows 95
-(as with the Unix operating system),
-all strings exchanged between Tcl and the operating system are
-.QW "char"
-based. On Windows NT, some strings exchanged between Tcl and the
-operating system are
-.QW "char"
-oriented while others are in Unicode. By
-convention, in Windows a TCHAR is a character in the ANSI code page
-on Windows 95 and a Unicode character on Windows NT.
-.PP
-If you planned to use the same
-.QW "char"
-based interfaces on both Windows
-95 and Windows NT, you could use \fBTcl_UtfToExternal\fR and
-\fBTcl_ExternalToUtf\fR (or their \fBTcl_DString\fR equivalents) with an
-encoding of NULL (the current system encoding). On the other hand,
-if you planned to use the Unicode interface when running on Windows NT
-and the
-.QW "char"
-interfaces when running on Windows 95, you would have
-to perform the following type of test over and over in your program
-(as represented in pseudo-code):
-.PP
-.CS
-if (running NT) {
- encoding <- Tcl_GetEncoding("unicode");
- nativeBuffer <- Tcl_UtfToExternal(encoding, utfBuffer);
- Tcl_FreeEncoding(encoding);
-} else {
- nativeBuffer <- Tcl_UtfToExternal(NULL, utfBuffer);
-}
-.CE
-.PP
-\fBTcl_WinUtfToTChar\fR and \fBTcl_WinTCharToUtf\fR automatically
-handle this test and use the proper encoding based on the current
-operating system. \fBTcl_WinUtfToTChar\fR returns a pointer to
-a TCHAR string, and \fBTcl_WinTCharToUtf\fR expects a TCHAR string
-pointer as the \fIsrc\fR string. Otherwise, these functions
-behave identically to \fBTcl_UtfToExternalDString\fR and
-\fBTcl_ExternalToUtfDString\fR.
+functions for converting between UTF-8 and Windows strings
+based on the TCHAR type which is by convention
+a Unicode character on Windows NT.
+These functions are essentially wrappers around
+\fBTcl_UtfToExternalDString\fR and
+\fBTcl_ExternalToUtfDString\fR that convert to and from the
+Unicode encoding.
.PP
\fBTcl_GetEncodingName\fR is roughly the inverse of \fBTcl_GetEncoding\fR.
Given an \fIencoding\fR, the return value is the \fIname\fR argument that
diff --git a/doc/exec.n b/doc/exec.n
index c3f316b..5b27e40 100644
--- a/doc/exec.n
+++ b/doc/exec.n
@@ -269,17 +269,13 @@ present, as is done when launching applications under wish. It is desirable
to have console applications hidden and detached. This is a designed-in
limitation as \fBexec\fR wants to communicate over pipes. The Expect
extension addresses this issue when communicating with a TUI application.
-.RE
-.TP
-\fBWindows NT\fR
-.
+.PP
When attempting to execute an application, \fBexec\fR first searches for
the name as it was specified. Then, in order, \fB.com\fR, \fB.exe\fR, and
\fB.bat\fR are appended to the end of the specified name and it searches
for the longer name. If a directory name was not specified as part of the
application name, the following directories are automatically searched in
order when attempting to locate the application:
-.RS
.IP \(bu 3
The directory from which the Tcl executable was loaded.
.IP \(bu 3
@@ -299,67 +295,6 @@ the caller must prepend the desired command with
because built-in commands are not implemented using executables.
.RE
.TP
-\fBWindows 9x\fR
-.
-When attempting to execute an application, \fBexec\fR first searches for
-the name as it was specified. Then, in order, \fB.com\fR, \fB.exe\fR, and
-\fB.bat\fR are appended to the end of the specified name and it searches
-for the longer name. If a directory name was not specified as part of the
-application name, the following directories are automatically searched in
-order when attempting to locate the application:
-.RS
-.IP \(bu 3
-The directory from which the Tcl executable was loaded.
-.IP \(bu 3
-The current directory.
-.IP \(bu 3
-The Windows 9x system directory.
-.IP \(bu 3
-The Windows 9x home directory.
-.IP \(bu 3
-The directories listed in the path.
-.RE
-.RS
-.PP
-In order to execute shell built-in commands like \fBdir\fR and \fBcopy\fR,
-the caller must prepend the desired command with
-.QW "\fBcommand.com /c\0\fR"
-because built-in commands are not implemented using executables.
-.PP
-Once a 16-bit DOS application has read standard input from a console and
-then quit, all subsequently run 16-bit DOS applications will see the
-standard input as already closed. 32-bit applications do not have this
-problem and will run correctly, even after a 16-bit DOS application thinks
-that standard input is closed. There is no known workaround for this bug
-at this time.
-.PP
-Redirection between the \fBNUL:\fR device and a 16-bit application does not
-always work. When redirecting from \fBNUL:\fR, some applications may hang,
-others will get an infinite stream of
-.QW 0x01
-bytes, and some will actually
-correctly get an immediate end-of-file; the behavior seems to depend upon
-something compiled into the application itself. When redirecting greater than
-4K or so to \fBNUL:\fR, some applications will hang. The above problems do not
-happen with 32-bit applications.
-.PP
-All DOS 16-bit applications are run synchronously. All standard input from
-a pipe to a 16-bit DOS application is collected into a temporary file; the
-other end of the pipe must be closed before the 16-bit DOS application
-begins executing. All standard output or error from a 16-bit DOS
-application to a pipe is collected into temporary files; the application
-must terminate before the temporary files are redirected to the next stage
-of the pipeline. This is due to a workaround for a Windows 95 bug in the
-implementation of pipes, and is how the standard Windows 95 DOS shell
-handles pipes itself.
-.PP
-Certain applications, such as \fBcommand.com\fR, should not be executed
-interactively. Applications which directly access the console window,
-rather than reading from their standard input and writing to their standard
-output may fail, hang Tcl, or even hang the system if their own private
-console window is not available to them.
-.RE
-.TP
\fBUnix\fR (including Mac OS X)
.
The \fBexec\fR command is fully functional and works as described.
diff --git a/doc/file.n b/doc/file.n
index 5ff45fd..4c6465a 100644
--- a/doc/file.n
+++ b/doc/file.n
@@ -241,11 +241,9 @@ as relative to the cwd). Furthermore,
paths are always expanded
to absolute form. When creating links on filesystems that either do not
support any links, or do not support the specific type requested, an
-error message will be returned. In particular Windows 95, 98 and ME do
-not support any links at present, but most Unix platforms support both
-symbolic and hard links (the latter for files only) and Windows
-NT/2000/XP (on NTFS drives) support symbolic
-directory links and hard file links.
+error message will be returned. Most Unix platforms support both
+symbolic and hard links (the latter for files only). Windows
+supports symbolic directory links and hard file links on NTFS drives.
.RE
.TP
\fBfile lstat \fIname varName\fR
diff --git a/doc/glob.n b/doc/glob.n
index 86e450b..a2cbce2 100644
--- a/doc/glob.n
+++ b/doc/glob.n
@@ -204,13 +204,7 @@ of the form
it refers to the home
directory of the user whose account information resides on the specified NT
domain server. Otherwise, user account information is obtained from
-the local computer. On Windows 95 and 98, \fBglob\fR accepted patterns
-like
-.QW .../
-and
-.QW ..../
-for successively higher up parent directories, but later versions of
-Windows do not accept these forms.
+the local computer.
.PP
Since the backslash character has a special meaning to the glob
command, glob patterns containing Windows style path separators need
diff --git a/doc/open.n b/doc/open.n
index 7fccdf1..3012460 100644
--- a/doc/open.n
+++ b/doc/open.n
@@ -370,9 +370,8 @@ works for serial ports from 1 to 9. An attempt to open a serial port that
does not exist or has a number greater than 9 will fail. An alternate
form of opening serial ports is to use the filename \fB//./comX\fR,
where X is any number that corresponds to a serial port.
-.RS
.PP
-.
+.RS
When running Tcl interactively, there may be some strange interactions
between the real console, if one is present, and a command pipeline that uses
standard input or output. If a command pipeline is opened for reading, some
@@ -384,6 +383,7 @@ application are competing for the console at the same time. If the command
pipeline is started from a script, so that Tcl is not accessing the console,
or if the command pipeline does not use standard input or output, but is
redirected from or to a file, then the above problems do not occur.
+.RE
.TP
\fBUnix\fR\0\0\0\0\0\0\0
.
diff --git a/doc/socket.n b/doc/socket.n
index 492ca66..275771d 100644
--- a/doc/socket.n
+++ b/doc/socket.n
@@ -190,7 +190,6 @@ sockets, this option returns a list of three elements; these are the
address, the host name and the port to which the peer socket is connected
or bound. If the host name cannot be computed, the second element of the
list is identical to the address, its first element.
-.RE
.TP
\fB\-connecting\fR
.
diff --git a/doc/tcltest.n b/doc/tcltest.n
index 8d2398b..29265be 100644
--- a/doc/tcltest.n
+++ b/doc/tcltest.n
@@ -642,14 +642,6 @@ This test can only be run on any Windows platform.
.
This test can only be run on any Windows NT platform.
.TP
-\fI95\fR
-.
-This test can only be run on any Windows 95 platform.
-.TP
-\fI98\fR
-.
-This test can only be run on any Windows 98 platform.
-.TP
\fImac\fR
.
This test can only be run on any Mac platform.
diff --git a/doc/tclvars.n b/doc/tclvars.n
index 48ab83a..a8fba47 100644
--- a/doc/tclvars.n
+++ b/doc/tclvars.n
@@ -308,18 +308,13 @@ is the value returned by \fBuname -m\fR.
\fBos\fR
.
The name of the operating system running on this machine,
-such as \fBWindows 95\fR, \fBWindows NT\fR, or \fBSunOS\fR.
+such as \fBWindows NT\fR or \fBSunOS\fR.
On UNIX machines, this is the value returned by \fBuname -s\fR.
-On Windows 95 and Windows 98, the value returned will be \fBWindows
-95\fR to provide better backwards compatibility to Windows 95; to
-distinguish between the two, check the \fBosVersion\fR.
.TP
\fBosVersion\fR
.
The version number for the operating system running on this machine.
-On UNIX machines, this is the value returned by \fBuname -r\fR. On
-Windows 95, the version will be 4.0; on Windows 98, the version will
-be 4.10.
+On UNIX machines, this is the value returned by \fBuname -r\fR.
.TP
\fBpathSeparator\fR
.VS 8.6
diff --git a/generic/regcomp.c b/generic/regcomp.c
index c93eb24..7ca4346 100644
--- a/generic/regcomp.c
+++ b/generic/regcomp.c
@@ -996,13 +996,13 @@ parseqatom(
switch (v->nexttype) {
case '*':
m = 0;
- n = INFINITY;
+ n = DUPINF;
qprefer = (v->nextvalue) ? LONGER : SHORTER;
NEXT();
break;
case '+':
m = 1;
- n = INFINITY;
+ n = DUPINF;
qprefer = (v->nextvalue) ? LONGER : SHORTER;
NEXT();
break;
@@ -1019,7 +1019,7 @@ parseqatom(
if (SEE(DIGIT)) {
n = scannum(v);
} else {
- n = INFINITY;
+ n = DUPINF;
}
if (m > n) {
ERR(REG_BADBR);
@@ -1217,8 +1217,8 @@ parseqatom(
*/
dupnfa(v->nfa, atom->begin, atom->end, s, atom->begin);
- assert(m >= 1 && m != INFINITY && n >= 1);
- repeat(v, s, atom->begin, m-1, (n == INFINITY) ? n : n-1);
+ assert(m >= 1 && m != DUPINF && n >= 1);
+ repeat(v, s, atom->begin, m-1, (n == DUPINF) ? n : n-1);
f = COMBINE(qprefer, atom->flags);
t = subre(v, '.', f, s, atom->end); /* prefix and atom */
NOERR();
@@ -1323,7 +1323,7 @@ repeat(
#define SOME 2
#define INF 3
#define PAIR(x, y) ((x)*4 + (y))
-#define REDUCE(x) ( ((x) == INFINITY) ? INF : (((x) > 1) ? SOME : (x)) )
+#define REDUCE(x) ( ((x) == DUPINF) ? INF : (((x) > 1) ? SOME : (x)) )
const int rm = REDUCE(m);
const int rn = REDUCE(n);
struct state *s, *s2;
@@ -2108,7 +2108,7 @@ stdump(
}
if (t->min != 1 || t->max != 1) {
fprintf(f, " {%d,", t->min);
- if (t->max != INFINITY) {
+ if (t->max != DUPINF) {
fprintf(f, "%d", t->max);
}
fprintf(f, "}");
diff --git a/generic/regexec.c b/generic/regexec.c
index ad4b6e6..3b9af3e 100644
--- a/generic/regexec.c
+++ b/generic/regexec.c
@@ -1122,7 +1122,7 @@ complicatedBackrefDissect(
*/
i = 0;
- for (p = begin; p <= stop && (i < max || max == INFINITY); p += len) {
+ for (p = begin; p <= stop && (i < max || max == DUPINF); p += len) {
if (v->g->compare(paren, p, len) != 0) {
break;
}
@@ -1137,7 +1137,7 @@ complicatedBackrefDissect(
if (p != end) { /* didn't consume all of it */
return REG_NOMATCH;
}
- if (min <= i && (i <= max || max == INFINITY)) {
+ if (min <= i && (i <= max || max == DUPINF)) {
return REG_OKAY;
}
return REG_NOMATCH; /* out of range */
diff --git a/generic/regguts.h b/generic/regguts.h
index b478e4c..1b6abe6 100644
--- a/generic/regguts.h
+++ b/generic/regguts.h
@@ -99,7 +99,7 @@
#define xxx 1
#define DUPMAX _POSIX2_RE_DUP_MAX
-#define INFINITY (DUPMAX+1)
+#define DUPINF (DUPMAX+1)
#define REMAGIC 0xfed7 /* magic number for main struct */
diff --git a/generic/tcl.h b/generic/tcl.h
index 95f2b3f..ae425bb 100644
--- a/generic/tcl.h
+++ b/generic/tcl.h
@@ -56,10 +56,10 @@ extern "C" {
#define TCL_MAJOR_VERSION 8
#define TCL_MINOR_VERSION 6
#define TCL_RELEASE_LEVEL TCL_FINAL_RELEASE
-#define TCL_RELEASE_SERIAL 3
+#define TCL_RELEASE_SERIAL 4
#define TCL_VERSION "8.6"
-#define TCL_PATCH_LEVEL "8.6.3"
+#define TCL_PATCH_LEVEL "8.6.4"
/*
*----------------------------------------------------------------------------
diff --git a/generic/tclCompCmdsGR.c b/generic/tclCompCmdsGR.c
index e2fb43d..b77c43c 100644
--- a/generic/tclCompCmdsGR.c
+++ b/generic/tclCompCmdsGR.c
@@ -1501,6 +1501,10 @@ TclCompileLreplaceCmd(
return TCL_ERROR;
}
+ if(idx2 != INDEX_END && idx2 < idx1) {
+ idx2 = idx1-1;
+ }
+
/*
* Work out what this [lreplace] is actually doing.
*/
diff --git a/generic/tclVar.c b/generic/tclVar.c
index ec4c13c..0228a2c 100644
--- a/generic/tclVar.c
+++ b/generic/tclVar.c
@@ -4746,7 +4746,7 @@ Tcl_GetVariableFullName(
} else if (iPtr->varFramePtr->procPtr) {
int index = varPtr - iPtr->varFramePtr->compiledLocals;
- if (index < iPtr->varFramePtr->numCompiledLocals) {
+ if (index >= 0 && index < iPtr->varFramePtr->numCompiledLocals) {
namePtr = localName(iPtr->varFramePtr, index);
Tcl_AppendObjToObj(objPtr, namePtr);
}
diff --git a/library/init.tcl b/library/init.tcl
index f1f7704..05ac4a3 100644
--- a/library/init.tcl
+++ b/library/init.tcl
@@ -16,7 +16,7 @@
if {[info commands package] == ""} {
error "version mismatch: library\nscripts expect Tcl version 7.5b1 or later but the loaded version is\nonly [info patchlevel]"
}
-package require -exact Tcl 8.6.3
+package require -exact Tcl 8.6.4
# Compute the auto path to use in this interpreter.
# The values on the path come from several locations:
diff --git a/library/tzdata/Africa/Asmera b/library/tzdata/Africa/Asmera
index 931c36d..ca8d123 100644
--- a/library/tzdata/Africa/Asmera
+++ b/library/tzdata/Africa/Asmera
@@ -1,5 +1,5 @@
# created by tools/tclZIC.tcl - do not edit
-if {![info exists TZData(Africa/Asmara)]} {
- LoadTimeZoneFile Africa/Asmara
+if {![info exists TZData(Africa/Nairobi)]} {
+ LoadTimeZoneFile Africa/Nairobi
}
-set TZData(:Africa/Asmera) $TZData(:Africa/Asmara)
+set TZData(:Africa/Asmera) $TZData(:Africa/Nairobi)
diff --git a/library/tzdata/America/Cancun b/library/tzdata/America/Cancun
index 1620b15..fe5a060 100644
--- a/library/tzdata/America/Cancun
+++ b/library/tzdata/America/Cancun
@@ -43,174 +43,5 @@ set TZData(:America/Cancun) {
{1382857200 -21600 0 CST}
{1396771200 -18000 1 CDT}
{1414306800 -21600 0 CST}
- {1428220800 -18000 1 CDT}
- {1445756400 -21600 0 CST}
- {1459670400 -18000 1 CDT}
- {1477810800 -21600 0 CST}
- {1491120000 -18000 1 CDT}
- {1509260400 -21600 0 CST}
- {1522569600 -18000 1 CDT}
- {1540710000 -21600 0 CST}
- {1554624000 -18000 1 CDT}
- {1572159600 -21600 0 CST}
- {1586073600 -18000 1 CDT}
- {1603609200 -21600 0 CST}
- {1617523200 -18000 1 CDT}
- {1635663600 -21600 0 CST}
- {1648972800 -18000 1 CDT}
- {1667113200 -21600 0 CST}
- {1680422400 -18000 1 CDT}
- {1698562800 -21600 0 CST}
- {1712476800 -18000 1 CDT}
- {1730012400 -21600 0 CST}
- {1743926400 -18000 1 CDT}
- {1761462000 -21600 0 CST}
- {1775376000 -18000 1 CDT}
- {1792911600 -21600 0 CST}
- {1806825600 -18000 1 CDT}
- {1824966000 -21600 0 CST}
- {1838275200 -18000 1 CDT}
- {1856415600 -21600 0 CST}
- {1869724800 -18000 1 CDT}
- {1887865200 -21600 0 CST}
- {1901779200 -18000 1 CDT}
- {1919314800 -21600 0 CST}
- {1933228800 -18000 1 CDT}
- {1950764400 -21600 0 CST}
- {1964678400 -18000 1 CDT}
- {1982818800 -21600 0 CST}
- {1996128000 -18000 1 CDT}
- {2014268400 -21600 0 CST}
- {2027577600 -18000 1 CDT}
- {2045718000 -21600 0 CST}
- {2059027200 -18000 1 CDT}
- {2077167600 -21600 0 CST}
- {2091081600 -18000 1 CDT}
- {2108617200 -21600 0 CST}
- {2122531200 -18000 1 CDT}
- {2140066800 -21600 0 CST}
- {2153980800 -18000 1 CDT}
- {2172121200 -21600 0 CST}
- {2185430400 -18000 1 CDT}
- {2203570800 -21600 0 CST}
- {2216880000 -18000 1 CDT}
- {2235020400 -21600 0 CST}
- {2248934400 -18000 1 CDT}
- {2266470000 -21600 0 CST}
- {2280384000 -18000 1 CDT}
- {2297919600 -21600 0 CST}
- {2311833600 -18000 1 CDT}
- {2329369200 -21600 0 CST}
- {2343283200 -18000 1 CDT}
- {2361423600 -21600 0 CST}
- {2374732800 -18000 1 CDT}
- {2392873200 -21600 0 CST}
- {2406182400 -18000 1 CDT}
- {2424322800 -21600 0 CST}
- {2438236800 -18000 1 CDT}
- {2455772400 -21600 0 CST}
- {2469686400 -18000 1 CDT}
- {2487222000 -21600 0 CST}
- {2501136000 -18000 1 CDT}
- {2519276400 -21600 0 CST}
- {2532585600 -18000 1 CDT}
- {2550726000 -21600 0 CST}
- {2564035200 -18000 1 CDT}
- {2582175600 -21600 0 CST}
- {2596089600 -18000 1 CDT}
- {2613625200 -21600 0 CST}
- {2627539200 -18000 1 CDT}
- {2645074800 -21600 0 CST}
- {2658988800 -18000 1 CDT}
- {2676524400 -21600 0 CST}
- {2690438400 -18000 1 CDT}
- {2708578800 -21600 0 CST}
- {2721888000 -18000 1 CDT}
- {2740028400 -21600 0 CST}
- {2753337600 -18000 1 CDT}
- {2771478000 -21600 0 CST}
- {2785392000 -18000 1 CDT}
- {2802927600 -21600 0 CST}
- {2816841600 -18000 1 CDT}
- {2834377200 -21600 0 CST}
- {2848291200 -18000 1 CDT}
- {2866431600 -21600 0 CST}
- {2879740800 -18000 1 CDT}
- {2897881200 -21600 0 CST}
- {2911190400 -18000 1 CDT}
- {2929330800 -21600 0 CST}
- {2942640000 -18000 1 CDT}
- {2960780400 -21600 0 CST}
- {2974694400 -18000 1 CDT}
- {2992230000 -21600 0 CST}
- {3006144000 -18000 1 CDT}
- {3023679600 -21600 0 CST}
- {3037593600 -18000 1 CDT}
- {3055734000 -21600 0 CST}
- {3069043200 -18000 1 CDT}
- {3087183600 -21600 0 CST}
- {3100492800 -18000 1 CDT}
- {3118633200 -21600 0 CST}
- {3132547200 -18000 1 CDT}
- {3150082800 -21600 0 CST}
- {3163996800 -18000 1 CDT}
- {3181532400 -21600 0 CST}
- {3195446400 -18000 1 CDT}
- {3212982000 -21600 0 CST}
- {3226896000 -18000 1 CDT}
- {3245036400 -21600 0 CST}
- {3258345600 -18000 1 CDT}
- {3276486000 -21600 0 CST}
- {3289795200 -18000 1 CDT}
- {3307935600 -21600 0 CST}
- {3321849600 -18000 1 CDT}
- {3339385200 -21600 0 CST}
- {3353299200 -18000 1 CDT}
- {3370834800 -21600 0 CST}
- {3384748800 -18000 1 CDT}
- {3402889200 -21600 0 CST}
- {3416198400 -18000 1 CDT}
- {3434338800 -21600 0 CST}
- {3447648000 -18000 1 CDT}
- {3465788400 -21600 0 CST}
- {3479702400 -18000 1 CDT}
- {3497238000 -21600 0 CST}
- {3511152000 -18000 1 CDT}
- {3528687600 -21600 0 CST}
- {3542601600 -18000 1 CDT}
- {3560137200 -21600 0 CST}
- {3574051200 -18000 1 CDT}
- {3592191600 -21600 0 CST}
- {3605500800 -18000 1 CDT}
- {3623641200 -21600 0 CST}
- {3636950400 -18000 1 CDT}
- {3655090800 -21600 0 CST}
- {3669004800 -18000 1 CDT}
- {3686540400 -21600 0 CST}
- {3700454400 -18000 1 CDT}
- {3717990000 -21600 0 CST}
- {3731904000 -18000 1 CDT}
- {3750044400 -21600 0 CST}
- {3763353600 -18000 1 CDT}
- {3781494000 -21600 0 CST}
- {3794803200 -18000 1 CDT}
- {3812943600 -21600 0 CST}
- {3826252800 -18000 1 CDT}
- {3844393200 -21600 0 CST}
- {3858307200 -18000 1 CDT}
- {3875842800 -21600 0 CST}
- {3889756800 -18000 1 CDT}
- {3907292400 -21600 0 CST}
- {3921206400 -18000 1 CDT}
- {3939346800 -21600 0 CST}
- {3952656000 -18000 1 CDT}
- {3970796400 -21600 0 CST}
- {3984105600 -18000 1 CDT}
- {4002246000 -21600 0 CST}
- {4016160000 -18000 1 CDT}
- {4033695600 -21600 0 CST}
- {4047609600 -18000 1 CDT}
- {4065145200 -21600 0 CST}
- {4079059200 -18000 1 CDT}
- {4096594800 -21600 0 CST}
+ {1422777600 -18000 0 EST}
}
diff --git a/library/tzdata/America/Santiago b/library/tzdata/America/Santiago
index 44be9f8..29c2a93 100644
--- a/library/tzdata/America/Santiago
+++ b/library/tzdata/America/Santiago
@@ -118,174 +118,5 @@ set TZData(:America/Santiago) {
{1378612800 -10800 1 CLST}
{1398567600 -14400 0 CLT}
{1410062400 -10800 1 CLST}
- {1430017200 -14400 0 CLT}
- {1441512000 -10800 1 CLST}
- {1461466800 -14400 0 CLT}
- {1472961600 -10800 1 CLST}
- {1492916400 -14400 0 CLT}
- {1504411200 -10800 1 CLST}
- {1524970800 -14400 0 CLT}
- {1535860800 -10800 1 CLST}
- {1556420400 -14400 0 CLT}
- {1567915200 -10800 1 CLST}
- {1587870000 -14400 0 CLT}
- {1599364800 -10800 1 CLST}
- {1619319600 -14400 0 CLT}
- {1630814400 -10800 1 CLST}
- {1650769200 -14400 0 CLT}
- {1662264000 -10800 1 CLST}
- {1682218800 -14400 0 CLT}
- {1693713600 -10800 1 CLST}
- {1714273200 -14400 0 CLT}
- {1725768000 -10800 1 CLST}
- {1745722800 -14400 0 CLT}
- {1757217600 -10800 1 CLST}
- {1777172400 -14400 0 CLT}
- {1788667200 -10800 1 CLST}
- {1808622000 -14400 0 CLT}
- {1820116800 -10800 1 CLST}
- {1840071600 -14400 0 CLT}
- {1851566400 -10800 1 CLST}
- {1872126000 -14400 0 CLT}
- {1883016000 -10800 1 CLST}
- {1903575600 -14400 0 CLT}
- {1915070400 -10800 1 CLST}
- {1935025200 -14400 0 CLT}
- {1946520000 -10800 1 CLST}
- {1966474800 -14400 0 CLT}
- {1977969600 -10800 1 CLST}
- {1997924400 -14400 0 CLT}
- {2009419200 -10800 1 CLST}
- {2029374000 -14400 0 CLT}
- {2040868800 -10800 1 CLST}
- {2061428400 -14400 0 CLT}
- {2072318400 -10800 1 CLST}
- {2092878000 -14400 0 CLT}
- {2104372800 -10800 1 CLST}
- {2124327600 -14400 0 CLT}
- {2135822400 -10800 1 CLST}
- {2155777200 -14400 0 CLT}
- {2167272000 -10800 1 CLST}
- {2187226800 -14400 0 CLT}
- {2198721600 -10800 1 CLST}
- {2219281200 -14400 0 CLT}
- {2230171200 -10800 1 CLST}
- {2250730800 -14400 0 CLT}
- {2262225600 -10800 1 CLST}
- {2282180400 -14400 0 CLT}
- {2293675200 -10800 1 CLST}
- {2313630000 -14400 0 CLT}
- {2325124800 -10800 1 CLST}
- {2345079600 -14400 0 CLT}
- {2356574400 -10800 1 CLST}
- {2376529200 -14400 0 CLT}
- {2388024000 -10800 1 CLST}
- {2408583600 -14400 0 CLT}
- {2419473600 -10800 1 CLST}
- {2440033200 -14400 0 CLT}
- {2451528000 -10800 1 CLST}
- {2471482800 -14400 0 CLT}
- {2482977600 -10800 1 CLST}
- {2502932400 -14400 0 CLT}
- {2514427200 -10800 1 CLST}
- {2534382000 -14400 0 CLT}
- {2545876800 -10800 1 CLST}
- {2565831600 -14400 0 CLT}
- {2577326400 -10800 1 CLST}
- {2597886000 -14400 0 CLT}
- {2609380800 -10800 1 CLST}
- {2629335600 -14400 0 CLT}
- {2640830400 -10800 1 CLST}
- {2660785200 -14400 0 CLT}
- {2672280000 -10800 1 CLST}
- {2692234800 -14400 0 CLT}
- {2703729600 -10800 1 CLST}
- {2723684400 -14400 0 CLT}
- {2735179200 -10800 1 CLST}
- {2755738800 -14400 0 CLT}
- {2766628800 -10800 1 CLST}
- {2787188400 -14400 0 CLT}
- {2798683200 -10800 1 CLST}
- {2818638000 -14400 0 CLT}
- {2830132800 -10800 1 CLST}
- {2850087600 -14400 0 CLT}
- {2861582400 -10800 1 CLST}
- {2881537200 -14400 0 CLT}
- {2893032000 -10800 1 CLST}
- {2912986800 -14400 0 CLT}
- {2924481600 -10800 1 CLST}
- {2945041200 -14400 0 CLT}
- {2955931200 -10800 1 CLST}
- {2976490800 -14400 0 CLT}
- {2987985600 -10800 1 CLST}
- {3007940400 -14400 0 CLT}
- {3019435200 -10800 1 CLST}
- {3039390000 -14400 0 CLT}
- {3050884800 -10800 1 CLST}
- {3070839600 -14400 0 CLT}
- {3082334400 -10800 1 CLST}
- {3102894000 -14400 0 CLT}
- {3113784000 -10800 1 CLST}
- {3134343600 -14400 0 CLT}
- {3145838400 -10800 1 CLST}
- {3165793200 -14400 0 CLT}
- {3177288000 -10800 1 CLST}
- {3197242800 -14400 0 CLT}
- {3208737600 -10800 1 CLST}
- {3228692400 -14400 0 CLT}
- {3240187200 -10800 1 CLST}
- {3260142000 -14400 0 CLT}
- {3271636800 -10800 1 CLST}
- {3292196400 -14400 0 CLT}
- {3303086400 -10800 1 CLST}
- {3323646000 -14400 0 CLT}
- {3335140800 -10800 1 CLST}
- {3355095600 -14400 0 CLT}
- {3366590400 -10800 1 CLST}
- {3386545200 -14400 0 CLT}
- {3398040000 -10800 1 CLST}
- {3417994800 -14400 0 CLT}
- {3429489600 -10800 1 CLST}
- {3449444400 -14400 0 CLT}
- {3460939200 -10800 1 CLST}
- {3481498800 -14400 0 CLT}
- {3492993600 -10800 1 CLST}
- {3512948400 -14400 0 CLT}
- {3524443200 -10800 1 CLST}
- {3544398000 -14400 0 CLT}
- {3555892800 -10800 1 CLST}
- {3575847600 -14400 0 CLT}
- {3587342400 -10800 1 CLST}
- {3607297200 -14400 0 CLT}
- {3618792000 -10800 1 CLST}
- {3639351600 -14400 0 CLT}
- {3650241600 -10800 1 CLST}
- {3670801200 -14400 0 CLT}
- {3682296000 -10800 1 CLST}
- {3702250800 -14400 0 CLT}
- {3713745600 -10800 1 CLST}
- {3733700400 -14400 0 CLT}
- {3745195200 -10800 1 CLST}
- {3765150000 -14400 0 CLT}
- {3776644800 -10800 1 CLST}
- {3796599600 -14400 0 CLT}
- {3808094400 -10800 1 CLST}
- {3828654000 -14400 0 CLT}
- {3839544000 -10800 1 CLST}
- {3860103600 -14400 0 CLT}
- {3871598400 -10800 1 CLST}
- {3891553200 -14400 0 CLT}
- {3903048000 -10800 1 CLST}
- {3923002800 -14400 0 CLT}
- {3934497600 -10800 1 CLST}
- {3954452400 -14400 0 CLT}
- {3965947200 -10800 1 CLST}
- {3986506800 -14400 0 CLT}
- {3997396800 -10800 1 CLST}
- {4017956400 -14400 0 CLT}
- {4029451200 -10800 1 CLST}
- {4049406000 -14400 0 CLT}
- {4060900800 -10800 1 CLST}
- {4080855600 -14400 0 CLT}
- {4092350400 -10800 1 CLST}
+ {1430017200 -10800 0 CLT}
}
diff --git a/library/tzdata/Antarctica/Palmer b/library/tzdata/Antarctica/Palmer
index e87b171..f12528b 100644
--- a/library/tzdata/Antarctica/Palmer
+++ b/library/tzdata/Antarctica/Palmer
@@ -81,174 +81,5 @@ set TZData(:Antarctica/Palmer) {
{1378612800 -10800 1 CLST}
{1398567600 -14400 0 CLT}
{1410062400 -10800 1 CLST}
- {1430017200 -14400 0 CLT}
- {1441512000 -10800 1 CLST}
- {1461466800 -14400 0 CLT}
- {1472961600 -10800 1 CLST}
- {1492916400 -14400 0 CLT}
- {1504411200 -10800 1 CLST}
- {1524970800 -14400 0 CLT}
- {1535860800 -10800 1 CLST}
- {1556420400 -14400 0 CLT}
- {1567915200 -10800 1 CLST}
- {1587870000 -14400 0 CLT}
- {1599364800 -10800 1 CLST}
- {1619319600 -14400 0 CLT}
- {1630814400 -10800 1 CLST}
- {1650769200 -14400 0 CLT}
- {1662264000 -10800 1 CLST}
- {1682218800 -14400 0 CLT}
- {1693713600 -10800 1 CLST}
- {1714273200 -14400 0 CLT}
- {1725768000 -10800 1 CLST}
- {1745722800 -14400 0 CLT}
- {1757217600 -10800 1 CLST}
- {1777172400 -14400 0 CLT}
- {1788667200 -10800 1 CLST}
- {1808622000 -14400 0 CLT}
- {1820116800 -10800 1 CLST}
- {1840071600 -14400 0 CLT}
- {1851566400 -10800 1 CLST}
- {1872126000 -14400 0 CLT}
- {1883016000 -10800 1 CLST}
- {1903575600 -14400 0 CLT}
- {1915070400 -10800 1 CLST}
- {1935025200 -14400 0 CLT}
- {1946520000 -10800 1 CLST}
- {1966474800 -14400 0 CLT}
- {1977969600 -10800 1 CLST}
- {1997924400 -14400 0 CLT}
- {2009419200 -10800 1 CLST}
- {2029374000 -14400 0 CLT}
- {2040868800 -10800 1 CLST}
- {2061428400 -14400 0 CLT}
- {2072318400 -10800 1 CLST}
- {2092878000 -14400 0 CLT}
- {2104372800 -10800 1 CLST}
- {2124327600 -14400 0 CLT}
- {2135822400 -10800 1 CLST}
- {2155777200 -14400 0 CLT}
- {2167272000 -10800 1 CLST}
- {2187226800 -14400 0 CLT}
- {2198721600 -10800 1 CLST}
- {2219281200 -14400 0 CLT}
- {2230171200 -10800 1 CLST}
- {2250730800 -14400 0 CLT}
- {2262225600 -10800 1 CLST}
- {2282180400 -14400 0 CLT}
- {2293675200 -10800 1 CLST}
- {2313630000 -14400 0 CLT}
- {2325124800 -10800 1 CLST}
- {2345079600 -14400 0 CLT}
- {2356574400 -10800 1 CLST}
- {2376529200 -14400 0 CLT}
- {2388024000 -10800 1 CLST}
- {2408583600 -14400 0 CLT}
- {2419473600 -10800 1 CLST}
- {2440033200 -14400 0 CLT}
- {2451528000 -10800 1 CLST}
- {2471482800 -14400 0 CLT}
- {2482977600 -10800 1 CLST}
- {2502932400 -14400 0 CLT}
- {2514427200 -10800 1 CLST}
- {2534382000 -14400 0 CLT}
- {2545876800 -10800 1 CLST}
- {2565831600 -14400 0 CLT}
- {2577326400 -10800 1 CLST}
- {2597886000 -14400 0 CLT}
- {2609380800 -10800 1 CLST}
- {2629335600 -14400 0 CLT}
- {2640830400 -10800 1 CLST}
- {2660785200 -14400 0 CLT}
- {2672280000 -10800 1 CLST}
- {2692234800 -14400 0 CLT}
- {2703729600 -10800 1 CLST}
- {2723684400 -14400 0 CLT}
- {2735179200 -10800 1 CLST}
- {2755738800 -14400 0 CLT}
- {2766628800 -10800 1 CLST}
- {2787188400 -14400 0 CLT}
- {2798683200 -10800 1 CLST}
- {2818638000 -14400 0 CLT}
- {2830132800 -10800 1 CLST}
- {2850087600 -14400 0 CLT}
- {2861582400 -10800 1 CLST}
- {2881537200 -14400 0 CLT}
- {2893032000 -10800 1 CLST}
- {2912986800 -14400 0 CLT}
- {2924481600 -10800 1 CLST}
- {2945041200 -14400 0 CLT}
- {2955931200 -10800 1 CLST}
- {2976490800 -14400 0 CLT}
- {2987985600 -10800 1 CLST}
- {3007940400 -14400 0 CLT}
- {3019435200 -10800 1 CLST}
- {3039390000 -14400 0 CLT}
- {3050884800 -10800 1 CLST}
- {3070839600 -14400 0 CLT}
- {3082334400 -10800 1 CLST}
- {3102894000 -14400 0 CLT}
- {3113784000 -10800 1 CLST}
- {3134343600 -14400 0 CLT}
- {3145838400 -10800 1 CLST}
- {3165793200 -14400 0 CLT}
- {3177288000 -10800 1 CLST}
- {3197242800 -14400 0 CLT}
- {3208737600 -10800 1 CLST}
- {3228692400 -14400 0 CLT}
- {3240187200 -10800 1 CLST}
- {3260142000 -14400 0 CLT}
- {3271636800 -10800 1 CLST}
- {3292196400 -14400 0 CLT}
- {3303086400 -10800 1 CLST}
- {3323646000 -14400 0 CLT}
- {3335140800 -10800 1 CLST}
- {3355095600 -14400 0 CLT}
- {3366590400 -10800 1 CLST}
- {3386545200 -14400 0 CLT}
- {3398040000 -10800 1 CLST}
- {3417994800 -14400 0 CLT}
- {3429489600 -10800 1 CLST}
- {3449444400 -14400 0 CLT}
- {3460939200 -10800 1 CLST}
- {3481498800 -14400 0 CLT}
- {3492993600 -10800 1 CLST}
- {3512948400 -14400 0 CLT}
- {3524443200 -10800 1 CLST}
- {3544398000 -14400 0 CLT}
- {3555892800 -10800 1 CLST}
- {3575847600 -14400 0 CLT}
- {3587342400 -10800 1 CLST}
- {3607297200 -14400 0 CLT}
- {3618792000 -10800 1 CLST}
- {3639351600 -14400 0 CLT}
- {3650241600 -10800 1 CLST}
- {3670801200 -14400 0 CLT}
- {3682296000 -10800 1 CLST}
- {3702250800 -14400 0 CLT}
- {3713745600 -10800 1 CLST}
- {3733700400 -14400 0 CLT}
- {3745195200 -10800 1 CLST}
- {3765150000 -14400 0 CLT}
- {3776644800 -10800 1 CLST}
- {3796599600 -14400 0 CLT}
- {3808094400 -10800 1 CLST}
- {3828654000 -14400 0 CLT}
- {3839544000 -10800 1 CLST}
- {3860103600 -14400 0 CLT}
- {3871598400 -10800 1 CLST}
- {3891553200 -14400 0 CLT}
- {3903048000 -10800 1 CLST}
- {3923002800 -14400 0 CLT}
- {3934497600 -10800 1 CLST}
- {3954452400 -14400 0 CLT}
- {3965947200 -10800 1 CLST}
- {3986506800 -14400 0 CLT}
- {3997396800 -10800 1 CLST}
- {4017956400 -14400 0 CLT}
- {4029451200 -10800 1 CLST}
- {4049406000 -14400 0 CLT}
- {4060900800 -10800 1 CLST}
- {4080855600 -14400 0 CLT}
- {4092350400 -10800 1 CLST}
+ {1430017200 -10800 0 CLT}
}
diff --git a/library/tzdata/Asia/Aden b/library/tzdata/Asia/Aden
index 399d9f0..5c5515e 100644
--- a/library/tzdata/Asia/Aden
+++ b/library/tzdata/Asia/Aden
@@ -1,6 +1,5 @@
# created by tools/tclZIC.tcl - do not edit
-
-set TZData(:Asia/Aden) {
- {-9223372036854775808 10794 0 LMT}
- {-631162794 10800 0 AST}
+if {![info exists TZData(Asia/Riyadh)]} {
+ LoadTimeZoneFile Asia/Riyadh
}
+set TZData(:Asia/Aden) $TZData(:Asia/Riyadh)
diff --git a/library/tzdata/Asia/Bahrain b/library/tzdata/Asia/Bahrain
index d4b7d2c..aab5b7d 100644
--- a/library/tzdata/Asia/Bahrain
+++ b/library/tzdata/Asia/Bahrain
@@ -1,7 +1,5 @@
# created by tools/tclZIC.tcl - do not edit
-
-set TZData(:Asia/Bahrain) {
- {-9223372036854775808 12140 0 LMT}
- {-1577935340 14400 0 GST}
- {76190400 10800 0 AST}
+if {![info exists TZData(Asia/Qatar)]} {
+ LoadTimeZoneFile Asia/Qatar
}
+set TZData(:Asia/Bahrain) $TZData(:Asia/Qatar)
diff --git a/library/tzdata/Asia/Kuwait b/library/tzdata/Asia/Kuwait
index 15d26db..e618c56 100644
--- a/library/tzdata/Asia/Kuwait
+++ b/library/tzdata/Asia/Kuwait
@@ -1,6 +1,5 @@
# created by tools/tclZIC.tcl - do not edit
-
-set TZData(:Asia/Kuwait) {
- {-9223372036854775808 11516 0 LMT}
- {-631163516 10800 0 AST}
+if {![info exists TZData(Asia/Riyadh)]} {
+ LoadTimeZoneFile Asia/Riyadh
}
+set TZData(:Asia/Kuwait) $TZData(:Asia/Riyadh)
diff --git a/library/tzdata/Asia/Muscat b/library/tzdata/Asia/Muscat
index a69b880..fdd34c1 100644
--- a/library/tzdata/Asia/Muscat
+++ b/library/tzdata/Asia/Muscat
@@ -1,6 +1,5 @@
# created by tools/tclZIC.tcl - do not edit
-
-set TZData(:Asia/Muscat) {
- {-9223372036854775808 14064 0 LMT}
- {-1577937264 14400 0 GST}
+if {![info exists TZData(Asia/Dubai)]} {
+ LoadTimeZoneFile Asia/Dubai
}
+set TZData(:Asia/Muscat) $TZData(:Asia/Dubai)
diff --git a/library/tzdata/Atlantic/Reykjavik b/library/tzdata/Atlantic/Reykjavik
index f0248ad..ad7f0db 100644
--- a/library/tzdata/Atlantic/Reykjavik
+++ b/library/tzdata/Atlantic/Reykjavik
@@ -1,15 +1,18 @@
# created by tools/tclZIC.tcl - do not edit
set TZData(:Atlantic/Reykjavik) {
- {-9223372036854775808 -5244 0 LMT}
- {-4197047556 -5268 0 RMT}
- {-1956609132 -3600 0 IST}
+ {-9223372036854775808 -5280 0 LMT}
+ {-1956609120 -3600 0 IST}
{-1668211200 0 1 ISST}
{-1647212400 -3600 0 IST}
{-1636675200 0 1 ISST}
{-1613430000 -3600 0 IST}
+ {-1605139200 0 1 ISST}
+ {-1581894000 -3600 0 IST}
+ {-1539561600 0 1 ISST}
+ {-1531350000 -3600 0 IST}
{-968025600 0 1 ISST}
- {-949615200 -3600 0 IST}
+ {-952293600 -3600 0 IST}
{-942008400 0 1 ISST}
{-920239200 -3600 0 IST}
{-909957600 0 1 ISST}
diff --git a/library/tzdata/Pacific/Easter b/library/tzdata/Pacific/Easter
index 000c6d1..f76594a 100644
--- a/library/tzdata/Pacific/Easter
+++ b/library/tzdata/Pacific/Easter
@@ -36,6 +36,7 @@ set TZData(:Pacific/Easter) {
{340171200 -21600 1 EASST}
{353473200 -25200 0 EAST}
{371620800 -21600 1 EASST}
+ {384836400 -18000 0 EAST}
{384922800 -21600 0 EAST}
{403070400 -18000 1 EASST}
{416372400 -21600 0 EAST}
@@ -102,174 +103,5 @@ set TZData(:Pacific/Easter) {
{1378612800 -18000 1 EASST}
{1398567600 -21600 0 EAST}
{1410062400 -18000 1 EASST}
- {1430017200 -21600 0 EAST}
- {1441512000 -18000 1 EASST}
- {1461466800 -21600 0 EAST}
- {1472961600 -18000 1 EASST}
- {1492916400 -21600 0 EAST}
- {1504411200 -18000 1 EASST}
- {1524970800 -21600 0 EAST}
- {1535860800 -18000 1 EASST}
- {1556420400 -21600 0 EAST}
- {1567915200 -18000 1 EASST}
- {1587870000 -21600 0 EAST}
- {1599364800 -18000 1 EASST}
- {1619319600 -21600 0 EAST}
- {1630814400 -18000 1 EASST}
- {1650769200 -21600 0 EAST}
- {1662264000 -18000 1 EASST}
- {1682218800 -21600 0 EAST}
- {1693713600 -18000 1 EASST}
- {1714273200 -21600 0 EAST}
- {1725768000 -18000 1 EASST}
- {1745722800 -21600 0 EAST}
- {1757217600 -18000 1 EASST}
- {1777172400 -21600 0 EAST}
- {1788667200 -18000 1 EASST}
- {1808622000 -21600 0 EAST}
- {1820116800 -18000 1 EASST}
- {1840071600 -21600 0 EAST}
- {1851566400 -18000 1 EASST}
- {1872126000 -21600 0 EAST}
- {1883016000 -18000 1 EASST}
- {1903575600 -21600 0 EAST}
- {1915070400 -18000 1 EASST}
- {1935025200 -21600 0 EAST}
- {1946520000 -18000 1 EASST}
- {1966474800 -21600 0 EAST}
- {1977969600 -18000 1 EASST}
- {1997924400 -21600 0 EAST}
- {2009419200 -18000 1 EASST}
- {2029374000 -21600 0 EAST}
- {2040868800 -18000 1 EASST}
- {2061428400 -21600 0 EAST}
- {2072318400 -18000 1 EASST}
- {2092878000 -21600 0 EAST}
- {2104372800 -18000 1 EASST}
- {2124327600 -21600 0 EAST}
- {2135822400 -18000 1 EASST}
- {2155777200 -21600 0 EAST}
- {2167272000 -18000 1 EASST}
- {2187226800 -21600 0 EAST}
- {2198721600 -18000 1 EASST}
- {2219281200 -21600 0 EAST}
- {2230171200 -18000 1 EASST}
- {2250730800 -21600 0 EAST}
- {2262225600 -18000 1 EASST}
- {2282180400 -21600 0 EAST}
- {2293675200 -18000 1 EASST}
- {2313630000 -21600 0 EAST}
- {2325124800 -18000 1 EASST}
- {2345079600 -21600 0 EAST}
- {2356574400 -18000 1 EASST}
- {2376529200 -21600 0 EAST}
- {2388024000 -18000 1 EASST}
- {2408583600 -21600 0 EAST}
- {2419473600 -18000 1 EASST}
- {2440033200 -21600 0 EAST}
- {2451528000 -18000 1 EASST}
- {2471482800 -21600 0 EAST}
- {2482977600 -18000 1 EASST}
- {2502932400 -21600 0 EAST}
- {2514427200 -18000 1 EASST}
- {2534382000 -21600 0 EAST}
- {2545876800 -18000 1 EASST}
- {2565831600 -21600 0 EAST}
- {2577326400 -18000 1 EASST}
- {2597886000 -21600 0 EAST}
- {2609380800 -18000 1 EASST}
- {2629335600 -21600 0 EAST}
- {2640830400 -18000 1 EASST}
- {2660785200 -21600 0 EAST}
- {2672280000 -18000 1 EASST}
- {2692234800 -21600 0 EAST}
- {2703729600 -18000 1 EASST}
- {2723684400 -21600 0 EAST}
- {2735179200 -18000 1 EASST}
- {2755738800 -21600 0 EAST}
- {2766628800 -18000 1 EASST}
- {2787188400 -21600 0 EAST}
- {2798683200 -18000 1 EASST}
- {2818638000 -21600 0 EAST}
- {2830132800 -18000 1 EASST}
- {2850087600 -21600 0 EAST}
- {2861582400 -18000 1 EASST}
- {2881537200 -21600 0 EAST}
- {2893032000 -18000 1 EASST}
- {2912986800 -21600 0 EAST}
- {2924481600 -18000 1 EASST}
- {2945041200 -21600 0 EAST}
- {2955931200 -18000 1 EASST}
- {2976490800 -21600 0 EAST}
- {2987985600 -18000 1 EASST}
- {3007940400 -21600 0 EAST}
- {3019435200 -18000 1 EASST}
- {3039390000 -21600 0 EAST}
- {3050884800 -18000 1 EASST}
- {3070839600 -21600 0 EAST}
- {3082334400 -18000 1 EASST}
- {3102894000 -21600 0 EAST}
- {3113784000 -18000 1 EASST}
- {3134343600 -21600 0 EAST}
- {3145838400 -18000 1 EASST}
- {3165793200 -21600 0 EAST}
- {3177288000 -18000 1 EASST}
- {3197242800 -21600 0 EAST}
- {3208737600 -18000 1 EASST}
- {3228692400 -21600 0 EAST}
- {3240187200 -18000 1 EASST}
- {3260142000 -21600 0 EAST}
- {3271636800 -18000 1 EASST}
- {3292196400 -21600 0 EAST}
- {3303086400 -18000 1 EASST}
- {3323646000 -21600 0 EAST}
- {3335140800 -18000 1 EASST}
- {3355095600 -21600 0 EAST}
- {3366590400 -18000 1 EASST}
- {3386545200 -21600 0 EAST}
- {3398040000 -18000 1 EASST}
- {3417994800 -21600 0 EAST}
- {3429489600 -18000 1 EASST}
- {3449444400 -21600 0 EAST}
- {3460939200 -18000 1 EASST}
- {3481498800 -21600 0 EAST}
- {3492993600 -18000 1 EASST}
- {3512948400 -21600 0 EAST}
- {3524443200 -18000 1 EASST}
- {3544398000 -21600 0 EAST}
- {3555892800 -18000 1 EASST}
- {3575847600 -21600 0 EAST}
- {3587342400 -18000 1 EASST}
- {3607297200 -21600 0 EAST}
- {3618792000 -18000 1 EASST}
- {3639351600 -21600 0 EAST}
- {3650241600 -18000 1 EASST}
- {3670801200 -21600 0 EAST}
- {3682296000 -18000 1 EASST}
- {3702250800 -21600 0 EAST}
- {3713745600 -18000 1 EASST}
- {3733700400 -21600 0 EAST}
- {3745195200 -18000 1 EASST}
- {3765150000 -21600 0 EAST}
- {3776644800 -18000 1 EASST}
- {3796599600 -21600 0 EAST}
- {3808094400 -18000 1 EASST}
- {3828654000 -21600 0 EAST}
- {3839544000 -18000 1 EASST}
- {3860103600 -21600 0 EAST}
- {3871598400 -18000 1 EASST}
- {3891553200 -21600 0 EAST}
- {3903048000 -18000 1 EASST}
- {3923002800 -21600 0 EAST}
- {3934497600 -18000 1 EASST}
- {3954452400 -21600 0 EAST}
- {3965947200 -18000 1 EASST}
- {3986506800 -21600 0 EAST}
- {3997396800 -18000 1 EASST}
- {4017956400 -21600 0 EAST}
- {4029451200 -18000 1 EASST}
- {4049406000 -21600 0 EAST}
- {4060900800 -18000 1 EASST}
- {4080855600 -21600 0 EAST}
- {4092350400 -18000 1 EASST}
+ {1430017200 -18000 0 EAST}
}
diff --git a/macosx/tclMacOSXNotify.c b/macosx/tclMacOSXNotify.c
index ef80192..9b7bd1a 100644
--- a/macosx/tclMacOSXNotify.c
+++ b/macosx/tclMacOSXNotify.c
@@ -1412,7 +1412,8 @@ UpdateWaitingListAndServiceEvents(
(tsdPtr->runLoopNestingLevel > 1
|| !tsdPtr->runLoopRunning)) {
tsdPtr->runLoopServicingEvents = 1;
- while (Tcl_ServiceAll() && tsdPtr->waitTime == 0) {}
+ /* This call seems to simply force event processing through and prevents hangups that have long been observed with Tk-Cocoa. */
+ Tcl_ServiceAll();
tsdPtr->runLoopServicingEvents = 0;
}
break;
diff --git a/tests/io.test b/tests/io.test
index cd8b014..06ae81d 100644
--- a/tests/io.test
+++ b/tests/io.test
@@ -8523,6 +8523,25 @@ test io-73.3 {[5adc350683] [gets] after EOF} -setup {
removeFile io-73.3
} -result {1 1 {more data} 0 {} 1}
+test io-73.4 {[5adc350683] [read] after EOF} -setup {
+ set fn [makeFile {} io-73.4]
+ set rfd [open $fn r]
+ set wfd [open $fn a]
+ chan configure $wfd -buffering line
+ read $rfd
+} -body {
+ set result [eof $rfd]
+ puts $wfd "more data"
+ lappend result [eof $rfd]
+ lappend result [read $rfd]
+ lappend result [eof $rfd]
+} -cleanup {
+ close $wfd
+ close $rfd
+ removeFile io-73.4
+} -result {1 1 {more data
+} 1}
+
# ### ### ### ######### ######### #########
# cleanup
diff --git a/tests/lreplace.test b/tests/lreplace.test
index b976788..d1319c6 100644
--- a/tests/lreplace.test
+++ b/tests/lreplace.test
@@ -137,6 +137,15 @@ test lreplace-4.1 {Bug ccc2c2cc98: lreplace edge case} {
test lreplace-4.2 {Bug ccc2c2cc98: lreplace edge case} {
lreplace { } 1 1
} {}
+test lreplace-4.3 {lreplace edge case} {
+ lreplace {1 2 3} 2 0
+} {1 2 3}
+test lreplace-4.4 {lreplace edge case} {
+ lreplace {1 2 3 4 5} 3 1
+} {1 2 3 4 5}
+test lreplace-4.5 {lreplace edge case} {
+ lreplace {1 2 3 4 5} 3 0 _
+} {1 2 3 _ 4 5}
# cleanup
catch {unset foo}
diff --git a/tools/tcltk-man2html.tcl b/tools/tcltk-man2html.tcl
index 89e8e5c..1ceceb9 100755
--- a/tools/tcltk-man2html.tcl
+++ b/tools/tcltk-man2html.tcl
@@ -667,7 +667,11 @@ try {
# ... but try to extract (name, version) from subdir contents
try {
- set f [open [file join $pkgsDir $dir configure.in]]
+ try {
+ set f [open [file join $pkgsDir $dir configure.in]]
+ } trap {POSIX ENOENT} {} {
+ set f [open [file join $pkgsDir $dir configure.ac]]
+ }
foreach line [split [read $f] \n] {
if {2 == [scan $line \
{ AC_INIT ( [%[^]]] , [%[^]]] ) } n v]} {
diff --git a/unix/configure b/unix/configure
index a578328..98f4696 100755
--- a/unix/configure
+++ b/unix/configure
@@ -1335,7 +1335,7 @@ ac_compiler_gnu=$ac_cv_c_compiler_gnu
TCL_VERSION=8.6
TCL_MAJOR_VERSION=8
TCL_MINOR_VERSION=6
-TCL_PATCH_LEVEL=".3"
+TCL_PATCH_LEVEL=".4"
VERSION=${TCL_VERSION}
EXTRA_INSTALL_BINARIES=${EXTRA_INSTALL_BINARIES:-"@:"}
diff --git a/unix/configure.in b/unix/configure.in
index 5123525..33219e8 100644
--- a/unix/configure.in
+++ b/unix/configure.in
@@ -25,7 +25,7 @@ m4_ifdef([SC_USE_CONFIG_HEADERS], [
TCL_VERSION=8.6
TCL_MAJOR_VERSION=8
TCL_MINOR_VERSION=6
-TCL_PATCH_LEVEL=".3"
+TCL_PATCH_LEVEL=".4"
VERSION=${TCL_VERSION}
EXTRA_INSTALL_BINARIES=${EXTRA_INSTALL_BINARIES:-"@:"}
diff --git a/unix/tcl.spec b/unix/tcl.spec
index 81f31da..1b8693f 100644
--- a/unix/tcl.spec
+++ b/unix/tcl.spec
@@ -4,7 +4,7 @@
Name: tcl
Summary: Tcl scripting language development environment
-Version: 8.6.3
+Version: 8.6.4
Release: 2
License: BSD
Group: Development/Languages
diff --git a/unix/tclConfig.h.in b/unix/tclConfig.h.in
index e55dcd0..10ae12f 100644
--- a/unix/tclConfig.h.in
+++ b/unix/tclConfig.h.in
@@ -4,9 +4,6 @@
#ifndef _TCLCONFIG
#define _TCLCONFIG
-/* Define if building universal (internal helper macro) */
-#undef AC_APPLE_UNIVERSAL_BUILD
-
/* Is gettimeofday() actually declared in <sys/time.h>? */
#undef GETTOD_NOT_DECLARED
@@ -214,10 +211,10 @@
/* Is 'struct stat64' in <sys/stat.h>? */
#undef HAVE_STRUCT_STAT64
-/* Define to 1 if `st_blksize' is a member of `struct stat'. */
+/* Define to 1 if `st_blksize' is member of `struct stat'. */
#undef HAVE_STRUCT_STAT_ST_BLKSIZE
-/* Define to 1 if `st_blocks' is a member of `struct stat'. */
+/* Define to 1 if `st_blocks' is member of `struct stat'. */
#undef HAVE_STRUCT_STAT_ST_BLOCKS
/* Define to 1 if you have the <sys/filio.h> header file. */
@@ -361,9 +358,6 @@
/* Define to the one symbol short name of this package. */
#undef PACKAGE_TARNAME
-/* Define to the home page for this package. */
-#undef PACKAGE_URL
-
/* Define to the version of this package. */
#undef PACKAGE_VERSION
@@ -442,17 +436,9 @@
/* Should we use vfork() instead of fork()? */
#undef USE_VFORK
-/* Define WORDS_BIGENDIAN to 1 if your processor stores words with the most
- significant byte first (like Motorola and SPARC, unlike Intel). */
-#if defined AC_APPLE_UNIVERSAL_BUILD
-# if defined __BIG_ENDIAN__
-# define WORDS_BIGENDIAN 1
-# endif
-#else
-# ifndef WORDS_BIGENDIAN
-# undef WORDS_BIGENDIAN
-# endif
-#endif
+/* Define to 1 if your processor stores words with the most significant byte
+ first (like Motorola and SPARC, unlike Intel and VAX). */
+#undef WORDS_BIGENDIAN
/* Are Darwin SUSv3 extensions available? */
#undef _DARWIN_C_SOURCE
@@ -507,7 +493,7 @@
/* Define to `int' if <sys/types.h> does not define. */
#undef pid_t
-/* Define to `unsigned int' if <sys/types.h> does not define. */
+/* Define to `unsigned' if <sys/types.h> does not define. */
#undef size_t
/* Define as int if socklen_t is not available */
diff --git a/win/configure b/win/configure
index b270648..bdfa908 100755
--- a/win/configure
+++ b/win/configure
@@ -1311,7 +1311,7 @@ SHELL=/bin/sh
TCL_VERSION=8.6
TCL_MAJOR_VERSION=8
TCL_MINOR_VERSION=6
-TCL_PATCH_LEVEL=".3"
+TCL_PATCH_LEVEL=".4"
VER=$TCL_MAJOR_VERSION$TCL_MINOR_VERSION
TCL_DDE_VERSION=1.4
diff --git a/win/configure.in b/win/configure.in
index 1bf901a..99d78f2 100644
--- a/win/configure.in
+++ b/win/configure.in
@@ -14,7 +14,7 @@ SHELL=/bin/sh
TCL_VERSION=8.6
TCL_MAJOR_VERSION=8
TCL_MINOR_VERSION=6
-TCL_PATCH_LEVEL=".3"
+TCL_PATCH_LEVEL=".4"
VER=$TCL_MAJOR_VERSION$TCL_MINOR_VERSION
TCL_DDE_VERSION=1.4
diff --git a/generic/tclIO.c b/generic/tclIO.c
index a9091af..c4757ea 100644
--- a/generic/tclIO.c
+++ b/generic/tclIO.c
@@ -1548,6 +1548,22 @@ Tcl_CreateChannel(
*/
assert(sizeof(Tcl_ChannelTypeVersion) == sizeof(Tcl_DriverBlockModeProc *));
+ assert(typePtr->typeName != NULL);
+ if (NULL == typePtr->closeProc) {
+ Tcl_Panic("channel type %s must define closeProc", typePtr->typeName);
+ }
+ if ((TCL_READABLE & mask) && (NULL == typePtr->inputProc)) {
+ Tcl_Panic("channel type %s must define inputProc when used for reader channel", typePtr->typeName);
+ }
+ if ((TCL_WRITABLE & mask) && (NULL == typePtr->outputProc)) {
+ Tcl_Panic("channel type %s must define outputProc when used for writer channel", typePtr->typeName);
+ }
+ if (NULL == typePtr->watchProc) {
+ Tcl_Panic("channel type %s must define watchProc", typePtr->typeName);
+ }
+ if ((NULL!=typePtr->wideSeekProc) && (NULL == typePtr->seekProc)) {
+ Tcl_Panic("channel type %s must define seekProc if defining wideSeekProc", typePtr->typeName);
+ }
/*
* JH: We could subsequently memset these to 0 to avoid the numerous
@@ -5735,8 +5751,8 @@ DoReadChars(
chanPtr = statePtr->topChanPtr;
TclChannelPreserve((Tcl_Channel)chanPtr);
- /* Must clear the BLOCKED flag here since we check before reading */
- ResetFlag(statePtr, CHANNEL_BLOCKED);
+ /* Must clear the BLOCKED|EOF flags here since we check before reading */
+ ResetFlag(statePtr, CHANNEL_BLOCKED|CHANNEL_EOF);
for (copied = 0; (unsigned) toRead > 0; ) {
copiedNow = -1;
if (statePtr->inQueueHead != NULL) {